@@ -21,10 +21,10 @@ class Puppet::Resource::Puppetdb < Puppet::Indirector::REST
     filter_expr = build_expression(filter)
     expr << filter_expr if filter_expr
 
-    query_string = "query=#{expr.to_pson}"
+    query_param = CGI.escape(expr.to_pson)
 
     begin
-      response = http_get(request, "/resources?#{query_string}", headers)
+      response = http_get(request, "/resources?query=#{query_param}", headers)
 
       unless response.is_a? Net::HTTPSuccess
         # Newline characters cause an HTTP error, so strip them
@@ -35,13 +35,16 @@ class Puppet::Resource::Puppetdb < Puppet::Indirector::REST
     end
 
     resources = PSON.load(response.body)
+
     resources.map do |res|
       params = res['parameters'] || {}
       params = params.map do |name,value|
         Puppet::Parser::Resource::Param.new(:name => name, :value => value)
       end
       attrs = {:parameters => params, :scope => scope}
-      Puppet::Parser::Resource.new(res['type'], res['title'], attrs)
+      result = Puppet::Parser::Resource.new(res['type'], res['title'], attrs)
+      result.collector_id = "#{res['certname']}|#{res['type']}|#{res['title']}"
+      result
     end
   end
 
@@ -62,16 +65,17 @@ class Puppet::Resource::Puppetdb < Puppet::Indirector::REST
 
   def build_predicate(op, field, value)
     # Title and tag aren't parameters, so we have to special-case them.
-    path = case field
-           when "tag", "title"
-             field
+    expr = case field
+           when "tag"
+             # Tag queries are case-insensitive, so downcase them
+             ["=", "tag", value.downcase]
+           when "title"
+             ["=", "title", value]
            else
-             ['parameter', field]
+             ["=", ['parameter', field], value]
            end
 
-    equal_expr = ['=', path, value]
-
-    op == '!=' ? ['not', equal_expr] : equal_expr
+    op == '!=' ? ['not', expr] : expr
   end
 
   def build_join(op, lhs, rhs)
